@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.699_009';
+our $VERSION = '1.699_010';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
@@ -128,25 +128,21 @@ sub condvar {
    require MCE::Shared::Condvar unless $INC{'MCE/Shared/Condvar.pm'};
    &share( MCE::Shared::Condvar->new(@_) );
 }
-
 sub minidb {
    shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
    require MCE::Shared::Minidb unless $INC{'MCE/Shared/Minidb.pm'};
    &share( MCE::Shared::Minidb->new(@_) );
 }
-
 sub queue {
    shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
    require MCE::Shared::Queue unless $INC{'MCE/Shared/Queue.pm'};
    &share( MCE::Shared::Queue->new(@_) );
 }
-
 sub scalar {
    shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
    require MCE::Shared::Scalar unless $INC{'MCE/Shared/Scalar.pm'};
    &share( MCE::Shared::Scalar->new(@_) );
 }
-
 sub sequence {
    shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
    require MCE::Shared::Sequence unless $INC{'MCE/Shared/Sequence.pm'};
@@ -175,6 +171,19 @@ sub array {
    $_item;
 }
 
+sub handle {
+   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   require MCE::Shared::Handle unless $INC{'MCE/Shared/Handle.pm'};
+
+   my $_item = &share( MCE::Shared::Handle->TIEHANDLE([]) );
+   my $_fh   = \do { local *HANDLE };
+
+   tie *{ $_fh }, 'MCE::Shared::Object', $_item;
+   $_item->OPEN(@_) if @_;
+
+   $_fh;
+}
+
 sub hash {
    shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
    require MCE::Shared::Hash unless $INC{'MCE/Shared/Hash.pm'};
@@ -213,19 +222,6 @@ sub ordhash {
    $_item;
 }
 
-sub handle {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
-   require MCE::Shared::Handle unless $INC{'MCE/Shared/Handle.pm'};
-
-   my $_item = &share( MCE::Shared::Handle->TIEHANDLE([]) );
-   my $_fh   = \do { local *HANDLE };
-
-   tie *{ $_fh }, 'MCE::Shared::Object', $_item;
-   $_item->OPEN(@_) if @_;
-
-   $_fh;
-}
-
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## PDL sharing -- construction takes place under the shared server-process.
@@ -261,17 +257,14 @@ if ($INC{'PDL.pm'}) {
 ##
 ###############################################################################
 
-sub TIEARRAY  { shift; MCE::Shared->array (@_) }
+sub TIEARRAY { shift; MCE::Shared->array(@_) }
 sub TIESCALAR { shift; MCE::Shared->scalar(@_) }
 
 sub TIEHASH {
    shift;
    if ( ref $_[0] eq 'HASH' && exists $_[0]->{'ordered'} ) {
-      shift()->{'ordered'}
-         ? MCE::Shared->ordhash(@_)
-         : MCE::Shared->hash(@_);
-   }
-   else {
+      shift()->{'ordered'} ? MCE::Shared->ordhash(@_) : MCE::Shared->hash(@_);
+   } else {
       MCE::Shared->hash(@_);
    }
 }
@@ -287,8 +280,7 @@ sub _croak {
    $_count = 0, %_lkup = ();
    if (defined $MCE::VERSION) {
       goto &MCE::_croak;
-   }
-   else {
+   } else {
       require MCE::Shared::Base unless $INC{'MCE/Shared/Base.pm'};
       goto &MCE::Shared::Base::_croak;
    }
@@ -322,7 +314,7 @@ MCE::Shared - MCE extension for sharing data between workers
 
 =head1 VERSION
 
-This document describes MCE::Shared version 1.699_009
+This document describes MCE::Shared version 1.699_010
 
 =head1 SYNOPSIS
 
