@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_009';
+our $VERSION = '1.699_010';
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
@@ -24,27 +24,34 @@ use overload (
    fallback => 1
 );
 
+no overloading;
+
+###############################################################################
+## ----------------------------------------------------------------------------
+## Based on Tie::StdArray from Tie::Array.
+##
+###############################################################################
+
 sub TIEARRAY {
    my $self = bless [], shift;
-   $self->PUSH(@_) if @_;
+   @{ $self } = @_ if @_;
+
    $self;
 }
 
 sub EXTEND { }
 
-# Based on Tie::StdArray from Tie::Array.
+sub FETCHSIZE { scalar @{ $_[0] } }
+sub STORESIZE { $#{ $_[0] } = $_[1] - 1 }
 
-sub FETCHSIZE { scalar @{$_[0]} }
-sub STORESIZE { $#{$_[0]} = $_[1] - 1 }
-
-sub STORE     { $_[0]->[$_[1]] = $_[2] }
-sub FETCH     { $_[0]->[$_[1]] }
-sub DELETE    { delete $_[0]->[$_[1]] }
-sub EXISTS    { exists $_[0]->[$_[1]] }
-sub CLEAR     { @{$_[0]} = () }
-sub POP       { pop(@{$_[0]}) }
+sub STORE     { $_[0]->[ $_[1] ] = $_[2] }
+sub FETCH     { $_[0]->[ $_[1] ] }
+sub DELETE    { delete $_[0]->[ $_[1] ] }
+sub EXISTS    { exists $_[0]->[ $_[1] ] }
+sub CLEAR     { @{ $_[0] } = () }
+sub POP       { pop(@{ $_[0] }) }
 sub PUSH      { my $o = shift; push(@$o, @_) }
-sub SHIFT     { shift(@{$_[0]}) }
+sub SHIFT     { shift(@{ $_[0] }) }
 sub UNSHIFT   { my $o = shift; unshift(@$o, @_) }
 
 # SPLICE ( offset, length [, list ] )
@@ -89,9 +96,7 @@ sub _find {
    my $params = ref($_[0]) eq 'HASH' ? shift : {};
    my $query  = shift;
 
-   MCE::Shared::Base::_find_array(
-      $self, $params, $query, 0 .. $#{ $self }
-   );
+   MCE::Shared::Base::_find_array( $self, $params, $query );
 }
 
 # clone ( key [, key, ... ] )
@@ -406,7 +411,7 @@ MCE::Shared::Array - Array helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Array version 1.699_009
+This document describes MCE::Shared::Array version 1.699_010
 
 =head1 SYNOPSIS
 
@@ -517,7 +522,19 @@ To be completed before the final 1.700 release.
 
 =item new ( val [, val, ... ] )
 
-=item new
+Constructs a new object, with an optional list of values.
+
+   # non-shared
+   use MCE::Shared::Array;
+
+   $ar = MCE::Shared::Array->new( @list );
+   $ar = MCE::Shared::Array->new( );
+
+   # shared
+   use MCE::Shared;
+
+   $ar = MCE::Shared->array( @list );
+   $ar = MCE::Shared->array( );
 
 =item clear
 
@@ -537,7 +554,7 @@ C<del> is an alias for C<delete>.
 
 =item flush
 
-Same as C<clone>. Clears all existing items before returning.
+Same as C<clone>. Though, clears all existing items before returning.
 
 =item get ( index )
 
@@ -555,8 +572,16 @@ Same as C<clone>. Clears all existing items before returning.
 
 =item len ( index )
 
+Returns the length of the value stored at index.
+
+   $len = $ar->len( 0 );
+
 =item len
 
+Returns the length of the list.
+
+   $len = $ar->len;
+
 =item mdel ( index [, index, ... ] )
 
 =item mexists ( index [, index, ... ] )
@@ -615,35 +640,51 @@ L<http://redis.io/commands#strings> with key representing the array index.
 
 =item append ( key, string )
 
-Append a value to a key.
+Appends a value to a key and returns its new length.
+
+   $len = $ar->append( 0, 'foo' );
 
 =item decr ( key )
 
-Decrement the value of a key by one and return its new value.
+Decrements the value of a key by one and returns its new value.
+
+   $num = $ar->decr( 0 );
 
 =item decrby ( key, number )
 
-Decrement the value of a key by the given number and return its new value.
+Decrements the value of a key by the given number and returns its new value.
+
+   $num = $ar->decrby( 0, 2 );
 
 =item getdecr ( key )
 
-Decrement the value of a key by one and return its old value.
+Decrements the value of a key by one and returns its old value.
+
+   $old = $ar->getdecr( 0 );
 
 =item getincr ( key )
 
-Increment the value of a key by one and return its old value.
+Increments the value of a key by one and returns its old value.
+
+   $old = $ar->getincr( 0 );
 
 =item getset ( key, value )
 
-Set the value of a key and return its old value.
+Sets the value of a key and returns its old value.
+
+   $old = $ar->getset( 0, 'baz' );
 
 =item incr ( key )
 
-Increment the value of a key by one and return its new value.
+Increments the value of a key by one and returns its new value.
+
+   $num = $ar->incr( 0 );
 
 =item incrby ( key, number )
 
-Increment the value of a key by the given number and return its new value.
+Increments the value of a key by the given number and returns its new value.
+
+   $num = $ar->incrby( 0, 2 );
 
 =back
 
