@@ -1,6 +1,6 @@
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## A fast, pure-Perl in-memory data structure store.
+## A pure-Perl in-memory data store.
 ##
 ###############################################################################
 
@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_009';
+our $VERSION = '1.699_010';
 
 use MCE::Shared::Base;
 use MCE::Shared::Ordhash;
@@ -25,6 +25,8 @@ use overload (
    fallback => 1
 );
 
+no overloading;
+
 sub new {
    # Parallel Hashes: [ HoH, HoA ]
    bless [
@@ -76,7 +78,7 @@ sub _hfind {
       $params->{'hfind'} = 1;
 
       MCE::Shared::Base::_find_hash(
-         $self->[0][0], $params, $query, $self->[0]->keys()
+         $self->[0][0], $params, $query, $self->[0]
       );
    }
 }
@@ -99,7 +101,7 @@ sub _lfind {
       $params->{'lfind'} = 1;
 
       MCE::Shared::Base::_find_hash(
-         $self->[1][0], $params, $query, $self->[1]->keys()
+         $self->[1][0], $params, $query, $self->[1]
       );
    }
 }
@@ -573,7 +575,7 @@ sub hset {
    return unless length($key);
    if ( @_ ) {
       $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-      @_ == 2
+      ( @_ == 2 )
          ? $self->[0][0]{ $key }->set(@_)
          : $self->[0][0]{ $key }->mset(@_);
    }
@@ -590,7 +592,7 @@ sub hget {
    return unless length($key);
    if ( @_ ) {
       return unless exists($self->[0][0]{ $key });
-      @_ == 1
+      ( @_ == 1 )
          ? $self->[0][0]{ $key }->get(@_)
          : $self->[0][0]{ $key }->mget(@_);
    }
@@ -607,7 +609,7 @@ sub hdel {
    return unless length($key);
    if ( @_ ) {
       return unless exists($self->[0][0]{ $key });
-      @_ == 1
+      ( @_ == 1 )
          ? $self->[0][0]{ $key }->del(@_)
          : $self->[0][0]{ $key }->mdel(@_);
    }
@@ -624,7 +626,7 @@ sub hexists {
    return '' unless length($key);
    if ( @_ ) {
       return '' unless exists($self->[0][0]{ $key });
-      @_ == 1
+      ( @_ == 1 )
          ? $self->[0][0]{ $key }->exists(@_)
          : $self->[0][0]{ $key }->mexists(@_);
    }
@@ -707,6 +709,12 @@ sub hpairs {
    }
 }
 
+# hshift ( )
+
+sub hshift {
+   $_[0]->[0]->shift();
+}
+
 # hsort ( "BY key   [ ASC | DESC ] [ ALPHA ]" )
 # hsort ( "BY field [ ASC | DESC ] [ ALPHA ]" )
 
@@ -719,73 +727,73 @@ sub hsort {
 # happend ( key, field, string )
 
 sub happend {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->append($field, $_[3]);
+   $self->[0][0]{ $key }->append(@_);
 }
 
 # hdecr ( key, field )
 
 sub hdecr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->decr($field);
+   $self->[0][0]{ $key }->decr(@_);
 }
 
 # hdecrby ( key, field, number )
 
 sub hdecrby {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->decrby($field, $_[3]);
+   $self->[0][0]{ $key }->decrby(@_);
 }
 
 # hincr ( key, field )
 
 sub hincr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->incr($field);
+   $self->[0][0]{ $key }->incr(@_);
 }
 
 # hincrby ( key, field, number )
 
 sub hincrby {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->incrby($field, $_[3]);
+   $self->[0][0]{ $key }->incrby(@_);
 }
 
 # hgetdecr ( key, field )
 
 sub hgetdecr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->getdecr($field);
+   $self->[0][0]{ $key }->getdecr(@_);
 }
 
 # hgetincr ( key, field )
 
 sub hgetincr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->getincr($field);
+   $self->[0][0]{ $key }->getincr(@_);
 }
 
 # hgetset ( key, field, value )
 
 sub hgetset {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[0]->set($key, _new_hash()) unless exists($self->[0][0]{ $key });
-   $self->[0][0]{ $key }->getset($field, $_[3]);
+   $self->[0][0]{ $key }->getset(@_);
 }
 
 # hlen ( key, field )
@@ -817,7 +825,7 @@ sub lset {
    return unless length($key);
    if ( @_ ) {
       $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-      @_ == 2
+      ( @_ == 2 )
          ? $self->[1][0]{ $key }->set(@_)
          : $self->[1][0]{ $key }->mset(@_);
    }
@@ -834,7 +842,7 @@ sub lget {
    return unless length($key);
    if ( @_ ) {
       return unless exists($self->[1][0]{ $key });
-      @_ == 1
+      ( @_ == 1 )
          ? $self->[1][0]{ $key }->get(@_)
          : $self->[1][0]{ $key }->mget(@_);
    }
@@ -851,7 +859,7 @@ sub ldel {
    return unless length($key);
    if ( @_ ) {
       return unless exists($self->[1][0]{ $key });
-      @_ == 1
+      ( @_ == 1 )
          ? $self->[1][0]{ $key }->del(@_)
          : $self->[1][0]{ $key }->mdel(@_);
    }
@@ -868,7 +876,7 @@ sub lexists {
    return '' unless length($key);
    if ( @_ ) {
       return '' unless exists($self->[1][0]{ $key });
-      @_ == 1
+      ( @_ == 1 )
          ? $self->[1][0]{ $key }->exists(@_)
          : $self->[1][0]{ $key }->mexists(@_);
    }
@@ -1002,6 +1010,12 @@ sub lpairs {
    }
 }
 
+# lshift ( )
+
+sub lshift {
+   $_[0]->[1]->shift();
+}
+
 # lsort ( "BY key   [ ASC | DESC ] [ ALPHA ]" )
 # lsort ( "BY index [ ASC | DESC ] [ ALPHA ]" )
 #
@@ -1022,73 +1036,73 @@ sub lsort {
 # lappend ( key, index, string )
 
 sub lappend {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->append($field, $_[3]);
+   $self->[1][0]{ $key }->append(@_);
 }
 
 # ldecr ( key, index )
 
 sub ldecr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->decr($field);
+   $self->[1][0]{ $key }->decr(@_);
 }
 
 # ldecrby ( key, index, number )
 
 sub ldecrby {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->decrby($field, $_[3]);
+   $self->[1][0]{ $key }->decrby(@_);
 }
 
 # lincr ( key, index )
 
 sub lincr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->incr($field);
+   $self->[1][0]{ $key }->incr(@_);
 }
 
 # lincrby ( key, index, number )
 
 sub lincrby {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->incrby($field, $_[3]);
+   $self->[1][0]{ $key }->incrby(@_);
 }
 
 # lgetdecr ( key, index )
 
 sub lgetdecr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->getdecr($field);
+   $self->[1][0]{ $key }->getdecr(@_);
 }
 
 # lgetincr ( key, index )
 
 sub lgetincr {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->getincr($field);
+   $self->[1][0]{ $key }->getincr(@_);
 }
 
 # lgetset ( key, index, value )
 
 sub lgetset {
-   my ( $self, $key, $field ) = @_;
-   return unless length($key) && length($field);
+   my ( $self, $key ) = ( shift, shift );
+   return unless length($key);
    $self->[1]->set($key, _new_list()) unless exists($self->[1][0]{ $key });
-   $self->[1][0]{ $key }->getset($field, $_[3]);
+   $self->[1][0]{ $key }->getset(@_);
 }
 
 # llen ( key, index )
@@ -1119,11 +1133,11 @@ __END__
 
 =head1 NAME
 
-MCE::Shared::Minidb - A fast, pure-Perl in-memory data structure store
+MCE::Shared::Minidb - A pure-Perl in-memory data store
 
 =head1 VERSION
 
-This document describes MCE::Shared::Minidb version 1.699_009
+This document describes MCE::Shared::Minidb version 1.699_010
 
 =head1 SYNOPSIS
 
@@ -1151,10 +1165,26 @@ This document describes MCE::Shared::Minidb version 1.699_009
 
 =head1 DESCRIPTION
 
-A simplistic in-memory NoSQL-like DB for use with L<MCE::Shared|MCE::Shared>.
+A tiny in-memory NoSQL-like database for use with L<MCE::Shared|MCE::Shared>.
 Although several methods resemble the C<Redis> API, it is not the intent for
 this module to become 100% compatible with it.
 
+This module was created mainly for having an efficient manner in which to
+manipulate hashes-of-hashes (HoH) and hashes-of-arrays (HoA) structures with
+MCE::Shared. Both are supported simulatenously due to being unique objects
+inside the C<$db> object.
+
+   sub new {
+      # Parallel Hashes: [ HoH, HoA ]
+      bless [
+         MCE::Shared::Ordhash->new(),  # Hash of Hashes (HoH)
+         MCE::Shared::Ordhash->new(),  # Hash of Arrays (HoA)
+      ], shift;
+   }
+
+   # (H)oH key => MCE::Shared::Hash->new();
+   # (H)oA key => MCE::Shared::Array->new()
+
 =head1 QUERY STRING
 
 Several methods in C<MCE::Shared::Minidb> receive a query string argument.
@@ -1193,6 +1223,70 @@ The shorter form without field names is allowed for HoA.
 
    "4 > 20 :and key =~ /baz/"  4 is the array index
   
+=head1 API DOCUMENTATION - DB
+
+=over 3
+
+=item new
+
+Constructs an empty in-memory C<HoH> and C<HoA> key-store database structure.
+
+   # non-shared
+   use MCE::Shared::Minidb;
+
+   $db = MCE::Shared::Minidb->new();
+
+   # shared
+   use MCE::Shared;
+
+   $db = MCE::Shared->minidb();
+
+=item dump ( "file.dat" )
+
+Dumps the in-memory content to a file.
+
+=item restore ( "file.dat" )
+
+Restores the in-memory content from a file.
+
+=item iterator ( ":hashes", "query string" )
+
+=item iterator ( ":hashes" )
+
+Returns a code reference that returns a single key => href pair.
+
+=item iterator ( ":hashes", key, "query string" )
+
+=item iterator ( ":hashes", key [, key, ... ] )
+
+Returns a code reference that returns a single key => value pair.
+
+=item iterator ( ":lists", "query string" )
+
+=item iterator ( ":lists" )
+
+Returns a code reference that returns a single key => aref pair.
+
+=item iterator ( ":lists", key, "query string" )
+
+=item iterator ( ":lists", key [, key, ... ] )
+
+Returns a code reference that returns a single key => value pair.
+
+=item select_aref ( ":hashes", "select string" )
+
+=item select_aref ( ":lists", "select string" )
+
+Returns [ key, aref ] pairs.
+
+=item select_href ( ":hashes", "select string" )
+
+=item select_href ( ":lists", "select string" )
+
+Returns [ key, href ] pairs.
+
+=back
+
 =head1 API DOCUMENTATION - HASHES ( HoH )
 
 To be completed before the final 1.700 release.
@@ -1235,32 +1329,85 @@ To be completed before the final 1.700 release.
 
 =item hpairs
 
+=item hshift
+
+Removes and returns the first key-value pair from the first-level hash (H)oH.
+In scalar context, only the value is returned. If the C<HASH> is empty, returns
+the undefined value.
+
+   ( $key, $href ) = $db->hshift;
+   $href = $db->hshift;
+
 =item hsort ( "BY key [ ASC | DESC ] [ ALPHA ]" )
 
 =item hsort ( "BY field [ ASC | DESC ] [ ALPHA ]" )
 
 =item happend ( key, field, string )
 
+Appends a value to key-field and returns its new length.
+
+   $len = $db->happend( $key, $field, 'foo' );
+
 =item hdecr ( key, field )
 
+Decrements the value of key-field by one and returns its new value.
+
+   $num = $db->hdecr( $key, $field );
+
 =item hdecrby ( key, field, number )
 
+Decrements the value of key-field by the given number and returns its new value.
+
+   $num = $db->hdecrby( $key, $field, 2 );
+
 =item hincr ( key, field )
 
+Increments the value of key-field by one and returns its new value.
+
+   $num = $db->hincr( $key, $field );
+
 =item hincrby ( key, field, number )
 
+Increments the value of key-field by the given number and returns its new value.
+
+   $num = $db->hincrby( $key, $field, 2 );
+
 =item hgetdecr ( key, field )
 
+Decrements the value of key-field by one and returns its old value.
+
+   $old = $db->hgetdecr( $key, $field );
+
 =item hgetincr ( key, field )
 
+Increments the value of key-field by one and returns its old value.
+
+   $old = $db->hgetincr( $key, $field );
+
 =item hgetset ( key, field, value )
 
+Sets the value of key-field and returns its old value.
+
+   $old = $db->hgetset( $key, $field, 'baz' );
+
 =item hlen ( key, field )
 
+Returns the length for the value stored at key-field.
+
+   $len = $db->hlen( $key, $field );
+
 =item hlen ( key )
 
+Returns the number of fields stored at key.
+
+   $len = $db->hlen( $key );
+
 =item hlen
 
+Returns the number of keys stored at the first-level hash (H)oH.
+
+   $len = $db->hlen;
+
 =back
 
 =head1 API DOCUMENTATION - LISTS ( HoA )
@@ -1291,6 +1438,11 @@ To be completed before the final 1.700 release.
 
 =item lpop ( key )
 
+Removes and return the first value of the second-level array Ho(A). If there
+are no elements in the array, returns the undefined value.
+
+   $value = $db->lpop( $key );
+
 =item lpush ( key, value [, value, ... ] )
 
 =item rpop ( key )
@@ -1315,6 +1467,16 @@ To be completed before the final 1.700 release.
 
 =item lpairs
 
+=item lshift
+
+Removes and returns the first key-value pair from the first-level hash (H)oA.
+In scalar context, only the value is returned. If the C<HASH> is empty, returns
+the undefined value. See C<lpop> to shift the first value of the second-level
+array Ho(A).
+
+   ( $key, $aref ) = $db->lshift;
+   $aref = $db->lshift;
+
 =item lsort ( "BY key [ ASC | DESC ] [ ALPHA ]" )
 
 =item lsort ( "BY index [ ASC | DESC ] [ ALPHA ]" )
@@ -1325,79 +1487,69 @@ To be completed before the final 1.700 release.
 
 =item lappend ( key, index, string )
 
+Appends a value to key-index and returns its new length.
+
+   $len = $db->lappend( $key, 0, 'foo' );
+
 =item ldecr ( key, index )
 
+Decrements the value of key-index by one and returns its new value.
+
+   $num = $db->ldecr( $key, 0 );
+
 =item ldecrby ( key, index, number )
 
+Decrements the value of key-index by the given number and returns its new value.
+
+   $num = $db->ldecrby( $key, 0, 2 );
+
 =item lincr ( key, index )
 
+Increments the value of key-index by one and returns its new value.
+
+   $num = $db->lincr( $key, 0 );
+
 =item lincrby ( key, index, number )
 
+Increments the value of key-index by the given number and returns its new value.
+
+   $num = $db->lincrby( $key, 0, 2 );
+
 =item lgetdecr ( key, index )
 
+Decrements the value of key-index by one and returns its old value.
+
+   $old = $db->lgetdecr( $key, 0 );
+
 =item lgetincr ( key, index )
 
+Increments the value of key-index by one and returns its old value.
+
+   $old = $db->lgetincr( $key, 0 );
+
 =item lgetset ( key, index, value )
 
+Sets the value of key-index and return its old value.
+
+   $old = $db->lgetset( $key, 0, 'baz' );
+
 =item llen ( key, index )
 
+Returns the length for the value stored at key-index.
+
+   $len = $db->llen( $key, $index );
+
 =item llen ( key )
 
+Returns the the size of the list stored at key.
+
+   $len = $db->llen( $key );
+
 =item llen
 
-=back
+Returns the number of keys stored at the first-level hash (H)oA.
 
-=head1 COMMON API
-
-=over 3
-
-=item new
-
-Constructs an empty C<Minidb> object.
-
-=item dump ( "file.dat" )
-
-Dumps the content to a file.
-
-=item restore ( "file.dat" )
-
-Restores the content from a file.
-
-=item iterator ( ":hashes", "query string" )
-
-=item iterator ( ":hashes" )
-
-Returns a code reference that returns a single key => href pair.
-
-=item iterator ( ":hashes", key, "query string" )
-
-=item iterator ( ":hashes", key [, key, ... ] )
-
-Returns a code reference that returns a single key => value pair.
-
-=item iterator ( ":lists", "query string" )
-
-=item iterator ( ":lists" )
-
-Returns a code reference that returns a single key => aref pair.
-
-=item iterator ( ":lists", key, "query string" )
-
-=item iterator ( ":lists", key [, key, ... ] )
-
-Returns a code reference that returns a single key => value pair.
-
-=item select_aref ( ":hashes", "select string" )
-
-=item select_aref ( ":lists", "select string" )
-
-Returns [ key, aref ] pairs.
-
-=item select_href ( ":hashes", "select string" )
-
-=item select_href ( ":lists", "select string" )
-
-Returns [ key, href ] pairs.
+   $len = $db->llen;
 
 =back
 
