@@ -4,11 +4,14 @@
 ##
 ## An optimized ordered-hash implementation inspired by Hash::Ordered v0.009.
 ##
-## -- Added SPLICE, sorting, plus extra capabilities for use with MCE::Hobo.
-## -- Keys garbage collection is done in-place for minimum memory consumption.
-## -- Revised tombstone deletion to ensure safety with varied usage patterns.
-## -- The indexed hash is filled on-demand to not impact subsequent stores.
-## -- Provides support for hash-like dereferencing, also on-demand.
+## 1. Added SPLICE, sorting, plus extra capabilities for use with MCE::Hobo
+##    and MCE::Shared::Minidb.
+##
+## 2. Revised tombstone deletion to not impact STORE, PUSH, UNSHIFT, and merge.
+##    Likewise, lesser impact in POP and SHIFT when [_INDX] is present.
+##    Ditto for forward and reverse deletes.
+##
+## 3. Purges TOMBSTONES in-place for lesser memory consumption.
 ##
 ###############################################################################
 
@@ -19,7 +22,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_009';
+our $VERSION = '1.699_010';
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
@@ -35,21 +38,20 @@ use constant {
    _BEGI => 3,  # begin ordered id for optimized shift/unshift
    _GCNT => 4,  # garbage count
    _ITER => 5,  # for tied hash support
-   _HREF => 6,  # for hash-like dereferencing
 };
 
 use overload (
    q("")    => \&MCE::Shared::Base::_stringify,
    q(0+)    => \&MCE::Shared::Base::_numify,
    q(%{})   => sub {
-      $_[0]->[_HREF] || do {
-         tie my %h, 'MCE::Shared::Ordhash::_href', $_[0];
-         $_[0]->[_HREF] = \%h;
-      };
+      tie my %h, 'MCE::Shared::Ordhash::_href', $_[0];
+      \%h;
    },
    fallback => 1
 );
 
+no overloading;
+
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## TIEHASH, STORE, FETCH, DELETE, FIRSTKEY, NEXTKEY, EXISTS, CLEAR, SCALAR
@@ -91,52 +93,60 @@ sub FETCH {
 
 sub DELETE {
    my ( $self, $key ) = @_;
+   return undef unless exists $self->[_DATA]{ $key };
 
-   if ( exists $self->[_DATA]{ $key } ) {
-      my $keys = $self->[_KEYS];
+   my $keys = $self->[_KEYS];
 
-      # check first key
-      if ( $key eq $keys->[0] ) {
-         $self->[_BEGI]++, delete $self->[_INDX]{ $key } if $self->[_INDX];
-         shift @{ $keys };
+   # check the first key
+   if ( $key eq $keys->[0] ) {
+      shift @{ $keys };
+
+      if ( $self->[_INDX] ) {
+         $self->[_BEGI]++, delete $self->[_INDX]{ $key };
+
+         # GC start of list
          if ( ref $keys->[0] ) {
-            my $i = 0; # GC start of list
-            $i++, shift @{ $keys } while ref( $keys->[0] );
+            my $i = 1; $i++ while ( ref $keys->[$i] );
             $self->[_BEGI] += $i, $self->[_GCNT] -= $i;
+            splice @{ $keys }, 0, $i;
          }
-      }
 
-      # check last key
-      elsif ( $key eq $keys->[-1] ) {
-         delete $self->[_INDX]{ $key } if $self->[_INDX];
-         pop @{ $keys };
+         $self->[_BEGI] = 0, $self->[_INDX] = undef unless @{ $keys };
+      }
+   }
+
+   # or maybe the last key
+   elsif ( $key eq $keys->[-1] ) {
+      pop @{ $keys };
+
+      if ( $self->[_INDX] ) {
+         delete $self->[_INDX]{ $key };
+
+         # GC end of list
          if ( ref $keys->[-1] ) {
-            my $i = 0; # GC end of list
-            $i++, pop @{ $keys } while ref( $keys->[-1] );
-            $self->[_GCNT] -= $i;
+            my $i = $#{ $keys } - 1; $i-- while ( ref $keys->[$i] );
+            $self->[_GCNT] -= $#{ $keys } - $i;
+            splice @{ $keys }, $i + 1;
          }
+
+         $self->[_BEGI] = 0, $self->[_INDX] = undef unless @{ $keys };
       }
-
-      # otherwise, key is in the middle
-      else {
-         my $indx = $self->[_INDX] || $self->_make_indx();
-         my $id   = delete $indx->{ $key };
-
-         # fill index on-demand; tombstone
-         $self->_fill_indx(), $id = delete $indx->{ $key } if !defined $id;
-         $keys->[ $id - $self->[_BEGI] ] = _TOMBSTONE;
-
-         # GC keys if more than half are tombstone
-         $self->purge() if ++$self->[_GCNT] > ( @{ $keys } >> 1 );
-      }
-
-      $self->[_BEGI] = 0, $self->[_INDX] = undef unless scalar @{ $keys };
-
-      delete $self->[_DATA]{ $key };
    }
+
+   # otherwise, the key is in the middle
    else {
-      undef;
+      my $indx = $self->[_INDX] || $self->_make_indx();
+      my $id   = delete $indx->{ $key };
+
+      # fill index on-demand; place tombstone
+      $self->_fill_indx(), $id = delete $indx->{ $key } if !defined $id;
+      $keys->[ $id - $self->[_BEGI] ] = _TOMBSTONE;
+
+      # GC keys if more than half are tombstone
+      $self->purge() if ++$self->[_GCNT] > ( @{ $keys } >> 1 );
    }
+
+   delete $self->[_DATA]{ $key };
 }
 
 # FIRSTKEY ( )
@@ -170,11 +180,10 @@ sub EXISTS {
 sub CLEAR {
    my ( $self ) = @_;
 
-   %{ $self->[_DATA] } = @{ $self->[_KEYS] } = (   ),
-      $self->[_BEGI]   =    $self->[_GCNT]   =   0  ,
+   %{ $self->[_DATA] } = @{ $self->[_KEYS] } = ( ),
+      $self->[_BEGI]   =    $self->[_GCNT]   =  0 ,
       $self->[_INDX]   = undef;
 
-   delete $self->[_HREF] if defined $self->[_HREF];
    delete $self->[_ITER] if defined $self->[_ITER];
 
    ();
@@ -198,19 +207,22 @@ sub POP {
    my ( $self ) = @_;
    my $keys = $self->[_KEYS];
    my $key  = pop @{ $keys };
-
    return unless defined $key;
 
    if ( $self->[_INDX] ) {
+      delete $self->[_INDX]{ $key };
+
+      # GC end of list
       if ( ref $keys->[-1] ) {
-         my $i = 0; # GC end of list
-         $i++, pop @{ $keys } while ref( $keys->[-1] );
-         $self->[_GCNT] -= $i;
+         my $i = $#{ $keys } - 1; $i-- while ( ref $keys->[$i] );
+         $self->[_GCNT] -= $#{ $keys } - $i;
+         splice @{ $keys }, $i + 1;
       }
-      $self->[_BEGI] = 0, $self->[_INDX] = undef unless scalar @{ $keys };
+
+      $self->[_BEGI] = 0, $self->[_INDX] = undef unless @{ $keys };
    }
 
-   return $key, delete $self->[_DATA]{$key};
+   return $key, delete $self->[_DATA]{ $key };
 }
 
 # PUSH ( key, value [, key, value, ... ] )
@@ -235,19 +247,22 @@ sub SHIFT {
    my ( $self ) = @_;
    my $keys = $self->[_KEYS];
    my $key  = shift @{ $keys };
-
    return unless defined $key;
 
    if ( $self->[_INDX] ) {
+      $self->[_BEGI]++, delete $self->[_INDX]{ $key };
+
+      # GC start of list
       if ( ref $keys->[0] ) {
-         my $i = 0; # GC start of list
-         $i++, shift @{ $keys } while ref( $keys->[0] );
+         my $i = 1; $i++ while ( ref $keys->[$i] );
          $self->[_BEGI] += $i, $self->[_GCNT] -= $i;
+         splice @{ $keys }, 0, $i;
       }
-      $self->[_BEGI] = 0, $self->[_INDX] = undef unless scalar @{ $keys };
+
+      $self->[_BEGI] = 0, $self->[_INDX] = undef unless @{ $keys };
    }
 
-   return $key, delete $self->[_DATA]{$key};
+   return $key, delete $self->[_DATA]{ $key };
 }
 
 # UNSHIFT ( key, value [, key, value, ... ] )
@@ -271,12 +286,11 @@ sub UNSHIFT {
 sub SPLICE {
    my ( $self, $off ) = ( shift, shift );
    my ( $data, $keys, $indx ) = @$self;
-   my ( $key, @ret );
-
-   return @ret unless defined $off;
+   return () unless defined $off;
 
    $self->purge() if $indx;
 
+   my ( $key, @ret );
    my $size = scalar @{ $keys };
    my $len  = @_ ? shift : $size - $off;
 
@@ -382,7 +396,7 @@ sub _find {
    my $query  = shift;
 
    MCE::Shared::Base::_find_hash(
-      $self->[_DATA], $params, $query, grep(!ref($_), @{ $self->[_KEYS] })
+      $self->[_DATA], $params, $query, $self
    );
 }
 
@@ -404,7 +418,7 @@ sub clone {
    }
    else {
       for my $key ( @{ $self->[_KEYS] } ) {
-         next if ref $key;
+         next if ( ref $key );
          push @keys, "$key" unless exists $data{ $key };
          $data{ $key } = $DATA->{ $key };
       }
@@ -573,22 +587,19 @@ sub mset {
 sub purge {
    my ( $self ) = @_;
 
-   # @{ $self->[_KEYS] } = grep !ref($_), @{ $self->[_KEYS] };
-   # Purging is done in-place for lesser memory consumption.
+   # Purges TOMBSTONES in-place for lesser memory consumption.
 
-   if ( $self->[_GCNT] ) {
+   if ( $self->[_INDX] ) {
       my ( $i, $keys ) = ( 0, $self->[_KEYS] );
+      $self->[_INDX] = undef, $self->[_BEGI] = $self->[_GCNT] = 0;
 
-      if ( @{ $keys } ) {
-         for ( 0 .. @{ $keys } - 1 ) {
-            next if ref( $keys->[$_] );
-            $keys->[ $i++ ] = $keys->[$_];
-         }
-         splice @{ $keys }, $i;
+      for ( 0 .. @{ $keys } - 1 ) {
+         next if ( ref $keys->[$_] );
+         $keys->[ $i++ ] = $keys->[$_];
       }
-   }
 
-   $self->[_INDX] = undef, $self->[_BEGI] = $self->[_GCNT] = 0;
+      splice @{ $keys }, $i;
+   }
 
    return;
 }
@@ -662,8 +673,6 @@ sub _reorder {
    my $self = shift; @{ $self->[_KEYS] } = @_;
    $self->[_INDX] = undef, $self->[_BEGI] = $self->[_GCNT] = 0;
 
-   delete $self->[_ITER] if exists $self->[_ITER];
-
    return;
 }
 
@@ -757,7 +766,7 @@ MCE::Shared::Ordhash - Ordered-hash helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Ordhash version 1.699_009
+This document describes MCE::Shared::Ordhash version 1.699_010
 
 =head1 SYNOPSIS
 
@@ -871,7 +880,19 @@ To be completed before the final 1.700 release.
 
 =item new ( key, value [, key, value, ... ] )
 
-=item new
+Constructs a new object, with an optional list of key-value pairs.
+
+   # non-shared
+   use MCE::Shared::Ordhash;
+
+   $ha = MCE::Shared::Ordhash->new( @pairs );
+   $ha = MCE::Shared::Ordhash->new( );
+
+   # shared
+   use MCE::Shared;
+
+   $ha = MCE::Shared->ordhash( @pairs );
+   $ha = MCE::Shared->ordhash( );
 
 =item clear
 
@@ -891,7 +912,7 @@ C<del> is an alias for C<delete>.
 
 =item flush
 
-Same as C<clone>. Clears all existing items before returning.
+Same as C<clone>. Though, clears all existing items before returning.
 
 =item get ( key )
 
@@ -909,8 +930,16 @@ Same as C<clone>. Clears all existing items before returning.
 
 =item len ( key )
 
+Returns the length of the value stored at key.
+
+   $len = $oh->len( $key );
+
 =item len
 
+Returns the number of keys stored in the hash.
+
+   $len = $oh->len;
+
 =item mdel ( key [, key, ... ] )
 
 =item mexists ( key [, key, ... ] )
@@ -971,35 +1000,51 @@ L<http://redis.io/commands#strings> with key representing the hash key.
 
 =item append ( key, string )
 
-Append a value to a key.
+Appends a value to a key and returns its new length.
+
+   $len = $oh->append( $key, 'foo' );
 
 =item decr ( key )
 
-Decrement the value of a key by one and return its new value.
+Decrements the value of a key by one and returns its new value.
+
+   $num = $oh->decr( $key );
 
 =item decrby ( key, number )
 
-Decrement the value of a key by the given number and return its new value.
+Decrements the value of a key by the given number and returns its new value.
+
+   $num = $oh->decrby( $key, 2 );
 
 =item getdecr ( key )
 
-Decrement the value of a key by one and return its old value.
+Decrements the value of a key by one and returns its old value.
+
+   $old = $oh->getdecr( $key );
 
 =item getincr ( key )
 
-Increment the value of a key by one and return its old value.
+Increments the value of a key by one and returns its old value.
+
+   $old = $oh->getincr( $key );
 
 =item getset ( key, value )
 
-Set the value of a key and return its old value.
+Sets the value of a key and returns its old value.
+
+   $old = $oh->getset( $key, 'baz' );
 
 =item incr ( key )
 
-Increment the value of a key by one and return its new value.
+Increments the value of a key by one and returns its new value.
+
+   $num = $oh->incr( $key );
 
 =item incrby ( key, number )
 
-Increment the value of a key by the given number and return its new value.
+Increments the value of a key by the given number and returns its new value.
+
+   $num = $oh->incrby( $key, 2 );
 
 =back
 
